Module phone

Module phone 

Bindings to the Phone Verification and Phone Intelligence apis.

Much of the documentation for this module comes from the Authy TOTP service documentation.

Structs

PhoneInfo
Returned when requesting info on a phone number
PhoneStart
Returned when initiating verification of a phone number.

Enums

ContactType
The contact type used when verifying a phone number

Functions

check
Verify phone verification code sent to user.
info
Request information on a phone number.
start
Initiate a phone verification check.