pub struct SessionRecord {
pub id: String,
pub scope: String,
pub token_hmac: Vec<u8>,
pub created_at: DateTime<Utc>,
pub expires_at: DateTime<Utc>,
pub revoked: bool,
pub label: Option<String>,
pub run_only: bool,
}Expand description
A session record stored in the vault (only the HMAC of the token is stored, not the token itself).
Fields
id: Stringscope: Stringtoken_hmac: Vec<u8>created_at: DateTime<Utc>expires_at: DateTime<Utc>revoked: boollabel: Option<String>run_only: boolWhen true, this token can only use run and list — not get, env, or export.