Module subprocess

Module subprocess 

Structs

NamingOptions
Options for naming environment variables when injecting secrets.

Functions

run_with_secrets
Run a subprocess with the given secrets injected as environment variables. Returns the exit code of the subprocess.
transform_name
Transform a secret name into an environment variable name.