Module types

Module types 

Structs

BTreeMap
An ordered map based on a B-Tree.
DateTime
ISO 8601 combined date and time with time zone.
PathBuf
An owned, mutable path (akin to String).
Utc
The UTC time zone. This is the most efficient time zone when you don’t need the local time. It is also used as an offset (which is also a dummy type).

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
Serialize
A data structure that can be serialized into any data format supported by Serde.

Derive Macros

Deserialize
Serialize